The data set rdata_Lorenz contains four columns: the first column is time (unitless) and the following three columns are the X, Y, Z components of the Lorenz system. The Lorenz system consists of three coupled first-order ordinary differential equations and is without a doubt one of the most famous nonlinear dynamical mathematical models, and represents a paradigmatic example for both theoretical and numerical investigations in checking some results in chaos theory (Polanco-Martínez 2022). For more details on how the rdata_Lorenz was created see Polanco-Martínez (2023).
data(rdata_Lorenz)One file in ASCII format containing 4 columns and 500 rows, columns are separated by spaces.